Clarified gauge arguments

Now the gauge names are `lattice` vs. `atomic` which should
clarify a bit more with respect to the older values: `cell`
and `atom`. The older values will still be respected.
A `comply_gauge` method should be used for external projects
if required.
